summaryrefslogtreecommitdiffstats
path: root/src/tdepowersave.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tdepowersave.cpp')
-rw-r--r--src/tdepowersave.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/tdepowersave.cpp b/src/tdepowersave.cpp
index 6779aae..7737089 100644
--- a/src/tdepowersave.cpp
+++ b/src/tdepowersave.cpp
@@ -101,7 +101,7 @@ tdepowersave::tdepowersave( bool force_acpi_check, bool trace_func ) : KSystemTr
connect(hwinfo, TQT_SIGNAL(ACStatus(bool)), this, TQT_SLOT(handleACStatusChange (bool)));
connect(hwinfo, TQT_SIGNAL(resumed(int)), this, TQT_SLOT(forwardResumeSignal(int)));
- // connect to error mesages
+ // connect to error messages
connect(autoSuspend, TQT_SIGNAL(displayErrorMsg(TQString)), this, TQT_SLOT(showErrorMessage(TQString)));
// connect to events
@@ -747,7 +747,7 @@ bool tdepowersave::do_suspend2disk(){
/*!
* \b TQT_SLOT to send the command for "suspend to RAM" to the TDE hardware library.
- * If there is a error while "suspend to RAM" the user get e messagebox.
+ * If there is a error while "suspend to RAM" the user get a messagebox.
* This function need a power management backend in TDE hardware library for "suspend to RAM".
* \return boolean with the result of the operation
* \retval true if successful
@@ -986,11 +986,11 @@ void tdepowersave::do_autosuspendWarn() {
/*!
* \b TQT_SLOT to send the related suspend command for autosuspend
* \param chancel boolean with info if the autosuspend should get chanceld
* \return boolean with the result of the operation
* \retval true if successful
* \retval false if command not supported or on any other error
- * \todo add check if the requested command is supported befor send and
+ * \todo add check if the requested command is supported before send and
* add message for this case to tell that maybe changed config!
*/
bool tdepowersave::do_autosuspend(bool chancel) {
@@ -1021,7 +1021,7 @@ bool tdepowersave::do_autosuspend(bool chancel) {
return false;
}
} else {
- kdDebug() << "The autosuspend was chanceled (via the chancel dialog), start again." << endl;
+ kdDebug() << "The autosuspend was canceled (via the cancel dialog), start again." << endl;
setAutoSuspend(false);
return false;
}
@@ -986,11 +986,11 @@ void tdepowersave::do_autosuspendWarn() {
/*!
* \b TQT_SLOT to send the related suspend command for autosuspend
- * \param chancel boolean with info if the autosuspend should get chanceld
+ * \param chancel boolean with info if the autosuspend should get canceled
* \return boolean with the result of the operation
* \retval true if successful